==> qtjambi-qt3dcore-5.15.3-sources.jar: io/qt/qt3d/core/QSkeleton.java <==
package io.qt.qt3d.core;


/**
 * <p>Holds the data for a skeleton to be used with skinned meshes</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dcore-qskeleton.html">Qt3DCore::QSkeleton</a></p>
 */
public class QSkeleton extends io.qt.qt3d.core.QAbstractSkeleton
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSkeleton.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qskeleton.html#rootJoint-prop">Qt3DCore::QSkeleton::rootJointChanged(Qt3DCore::QJoint*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="rootJoint")
    public final Signal1<io.qt.qt3d.core.QJoint> rootJointChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QSkeleton(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSkeleton() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qskeleton.html#QSkeleton">Qt3DCore::QSkeleton::QSkeleton(Qt3DCore::QNode*)</a></p>
     */
    public QSkeleton(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSkeleton instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qskeleton.html#rootJoint-prop">Qt3DCore::QSkeleton::rootJoint()const</a></p>
     */
    @io.qt.QtPropertyReader(name="rootJoint")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QJoint rootJoint(){
        return rootJoint_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QJoint rootJoint_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qskeleton.html#rootJoint-prop">Qt3DCore::QSkeleton::setRootJoint(Qt3DCore::QJoint*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="rootJoint")
    public final void setRootJoint(io.qt.qt3d.core.QJoint rootJoint){
        setRootJoint_native_Qt3DCore_QJoint_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rootJoint));
    }
    
    private native void setRootJoint_native_Qt3DCore_QJoint_ptr(long __this__nativeId, long rootJoint);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSkeleton(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSkeleton(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSkeleton instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QSkeleton.java <==
package io.qt.qt3d.core;


/**
 * <p>Holds the data for a skeleton to be used with skinned meshes</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qskeleton.html">Qt3DCore::QSkeleton</a></p>
 */
public class QSkeleton extends io.qt.qt3d.core.QAbstractSkeleton
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSkeleton.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qskeleton.html#rootJoint-prop">Qt3DCore::QSkeleton::rootJointChanged(Qt3DCore::QJoint*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="rootJoint")
    public final Signal1<io.qt.qt3d.core.QJoint> rootJointChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QSkeleton(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSkeleton() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qskeleton.html#QSkeleton">Qt3DCore::QSkeleton::QSkeleton(Qt3DCore::QNode*)</a></p>
     */
    public QSkeleton(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSkeleton instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qskeleton.html#rootJoint-prop">Qt3DCore::QSkeleton::rootJoint()const</a></p>
     */
    @io.qt.QtPropertyReader(name="rootJoint")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QJoint rootJoint(){
        return rootJoint_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QJoint rootJoint_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qskeleton.html#rootJoint-prop">Qt3DCore::QSkeleton::setRootJoint(Qt3DCore::QJoint*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="rootJoint")
    public final void setRootJoint(io.qt.qt3d.core.QJoint rootJoint){
        setRootJoint_native_Qt3DCore_QJoint_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rootJoint));
    }
    
    private native void setRootJoint_native_Qt3DCore_QJoint_ptr(long __this__nativeId, long rootJoint);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSkeleton(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSkeleton(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSkeleton instance, QDeclarativeConstructor constructor);
    
}
